package com.qianhe.system.service.impl;

import com.qianhe.common.utils.DateUtils;
import com.qianhe.system.domain.WaterGoods;
import com.qianhe.system.mapper.WaterGoodsMapper;
import com.qianhe.system.service.IWaterGoodsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 商品Service业务层处理
 *
 * @author qianhe
 * @date 2023-11-23
 */
@Service
public class WaterGoodsServiceImpl implements IWaterGoodsService
{
    @Autowired
    private WaterGoodsMapper waterGoodsMapper;

    /**
     * 查询商品
     *
     * @param id 商品主键
     * @return 商品
     */
    @Override
    public WaterGoods selectWaterGoodsById(Long id)
    {
        return waterGoodsMapper.selectWaterGoodsById(id);
    }

    /**
     * 查询商品列表
     *
     * @param waterGoods 商品
     * @return 商品
     */
    @Override
    public List<WaterGoods> selectWaterGoodsList(WaterGoods waterGoods)
    {
        return waterGoodsMapper.selectWaterGoodsList(waterGoods);
    }

    /**
     * 新增商品
     *
     * @param waterGoods 商品
     * @return 结果
     */
    @Override
    public int insertWaterGoods(WaterGoods waterGoods)
    {
        waterGoods.setCreateTime(DateUtils.getNowDate());
        return waterGoodsMapper.insertWaterGoods(waterGoods);
    }

    /**
     * 修改商品
     *
     * @param waterGoods 商品
     * @return 结果
     */
    @Override
    public int updateWaterGoods(WaterGoods waterGoods)
    {
        return waterGoodsMapper.updateWaterGoods(waterGoods);
    }

    /**
     * 批量删除商品
     *
     * @param ids 需要删除的商品主键
     * @return 结果
     */
    @Override
    public int deleteWaterGoodsByIds(Long[] ids)
    {
        return waterGoodsMapper.deleteWaterGoodsByIds(ids);
    }

    /**
     * 删除商品信息
     *
     * @param id 商品主键
     * @return 结果
     */
    @Override
    public int deleteWaterGoodsById(Long id)
    {
        return waterGoodsMapper.deleteWaterGoodsById(id);
    }
}
